==> views_slideshow_xtra-7.x-3.4.tar.gz: views_slideshow_xtra/views_slideshow_xtra_overlay/js/views_slideshow_xtra_overlay.js <==
/**
 * @file
 * Views Slideshow Xtra Javascript.
 */
(function ($) {
  Drupal.behaviors.viewsSlideshowXtraOverlay = {
    attach: function (context) {
      
      /*
      var pageX = 0, pageY = 0, timeout;
      $('.views_slideshow_main').each(function() {
        if ($('.views-slideshow-xtra-overlay-row' , $(this)).length) {
          
          // Optionally pause after mouse movement.
          var view = $(this).parent().parent().parent();
          var viewClasses = classList(view);
          
          $.each( viewClasses, function(index, item) {
            // We need this code because the id of the element selected will be something like:
            // "views_slideshow_cycle_main_views_slideshow_xtra_example-page"
            // We don't want to reference the string "cycle" in our code, and there is not a way to 
            // get the "View ID - Display ID" substring from the id string, unless the string "cycle"
            // is referenced in a string manipulation function.
            
            // Get the View ID
            if((/^view-id-/).test(item)) {
              viewId = item.substring('view-id-'.length);
            }
  
            // Get the Display ID
            if((/^view-display-id-/).test(item)) {
              viewDisplayId = item.substring('view-display-id-'.length);
            }
            
          });
          
          if(typeof viewId != "undefined") {
            var settings = Drupal.settings.viewsSlideshowXtraOverlay[viewId + '-' + viewDisplayId];
            if (settings.hasOwnProperty('pauseAfterMouseMove')) {
              var pauseAfterMouseMove = settings.pauseAfterMouseMove;
              if (pauseAfterMouseMove > 0) {
                $(this).mousemove(function(e) {
                  if (pageX - e.pageX > 5 || pageY - e.pageY > 5) {
                    Drupal.viewsSlideshow.action({ "action": 'pause', "slideshowID": viewId + '-' + viewDisplayId });
                    clearTimeout(timeout);
                    timeout = setTimeout(function() {
                        Drupal.viewsSlideshow.action({ "action": 'play', "slideshowID": viewId + '-' + viewDisplayId });
                        }, 2000);
                  }
                  pageX = e.pageX;
                  pageY = e.pageY;
                });
              }
            }
          }
        } 
      });
      */
      
      // Move the Views Attachment Overlays into the slideshow main slide area.
      $('[id^="views-slideshow-xtra-overlay-"]:not(.views-slideshow-xtra-overlay-processed)').addClass('views-slideshow-xtra-overlay-processed').each(function() {
        // Get the slide box.
        var slideArea = $(this).parent().parent().parent().parent().find('.views_slideshow_main');

        // Remove the views slideshow xtra html from the dom
        var xtraHTML = $(this).detach();

        // Attach the views slideshow xtra html to below the main slide.
        $(xtraHTML).appendTo(slideArea);

      });
    }
  };

  Drupal.viewsSlideshowXtraOverlay = Drupal.viewsSlideshowXtraOverlay || {};

  Drupal.viewsSlideshowXtraOverlay.transitionBegin = function (options) {
    
    // Example slideshowID: views_slideshow_xtra_example-page

    // Hide all overlays for all slides.
    $('#views_slideshow_cycle_main_' + options.slideshowID + ' .views-slideshow-xtra-overlay-row').hide();

    // Show the overlays for the current slide.
    $('#views_slideshow_cycle_main_' + options.slideshowID + ' [id^="views-slideshow-xtra-overlay-"]' + ' .views-slideshow-xtra-overlay-row-' + options.slideNum).each(function() {

      var overlay = $(this);
      var overlayContainerId = overlay.parent().attr('id');
      var lastDashPos = overlayContainerId.lastIndexOf('-');
      var currentDisplay = overlayContainerId.substr(lastDashPos + 1);
      var settings = Drupal.settings.viewsSlideshowXtraOverlay[currentDisplay];

      // Fade in or show overlay with optional delay.
      setTimeout(function() {
        if(settings.overlayFadeIn) {
          overlay.fadeIn(settings.overlayFadeIn);    
        } else {
          overlay.show();
        }
      },
        settings.overlayDelay
      );
      
      // Fade out.
      if(settings.overlayFadeOut) {
        setTimeout(function() {
          overlay.fadeOut(settings.overlayFadeOut);
        },
        settings.overlayFadeOutDelay
        );
      }
      
    });
  };

  function classList(elem){
    var classList = elem.attr('class').split(/\s+/);
     var classes = new Array(classList.length);
     $.each( classList, function(index, item){
         classes[index] = item;
     });

     return classes;
  }
  
})(jQuery);

==> views_slideshow_xtra-7.x-3.5.tar.gz: views_slideshow_xtra/views_slideshow_xtra_overlay/js/views_slideshow_xtra_overlay.js <==
/**
 * @file
 * Views Slideshow Xtra Javascript.
 */
(function ($) {
  Drupal.behaviors.viewsSlideshowXtraOverlay = {
    attach: function (context) {
      
      /*
      var pageX = 0, pageY = 0, timeout;
      $('.views_slideshow_main').each(function() {
        if ($('.views-slideshow-xtra-overlay-row' , $(this)).length) {
          
          // Optionally pause after mouse movement.
          var view = $(this).parent().parent().parent();
          var viewClasses = classList(view);
          
          $.each( viewClasses, function(index, item) {
            // We need this code because the id of the element selected will be something like:
            // "views_slideshow_cycle_main_views_slideshow_xtra_example-page"
            // We don't want to reference the string "cycle" in our code, and there is not a way to 
            // get the "View ID - Display ID" substring from the id string, unless the string "cycle"
            // is referenced in a string manipulation function.
            
            // Get the View ID
            if((/^view-id-/).test(item)) {
              viewId = item.substring('view-id-'.length);
            }
  
            // Get the Display ID
            if((/^view-display-id-/).test(item)) {
              viewDisplayId = item.substring('view-display-id-'.length);
            }
            
          });
          
          if(typeof viewId != "undefined") {
            var settings = Drupal.settings.viewsSlideshowXtraOverlay[viewId + '-' + viewDisplayId];
            if (settings.hasOwnProperty('pauseAfterMouseMove')) {
              var pauseAfterMouseMove = settings.pauseAfterMouseMove;
              if (pauseAfterMouseMove > 0) {
                $(this).mousemove(function(e) {
                  if (pageX - e.pageX > 5 || pageY - e.pageY > 5) {
                    Drupal.viewsSlideshow.action({ "action": 'pause', "slideshowID": viewId + '-' + viewDisplayId });
                    clearTimeout(timeout);
                    timeout = setTimeout(function() {
                        Drupal.viewsSlideshow.action({ "action": 'play', "slideshowID": viewId + '-' + viewDisplayId });
                        }, 2000);
                  }
                  pageX = e.pageX;
                  pageY = e.pageY;
                });
              }
            }
          }
        } 
      });
      */
      
      // Move the Views Attachment Overlays into the slideshow main slide area.
      $('[id^="views-slideshow-xtra-overlay-"]:not(.views-slideshow-xtra-overlay-processed)').addClass('views-slideshow-xtra-overlay-processed').each(function() {
        // Get the slide box.
        var slideArea = $(this).parent().parent().parent().parent().find('.views_slideshow_main');

        // Remove the views slideshow xtra html from the dom
        var xtraHTML = $(this).detach();

        // Attach the views slideshow xtra html to below the main slide.
        $(xtraHTML).appendTo(slideArea);

      });
    }
  };

  Drupal.viewsSlideshowXtraOverlay = Drupal.viewsSlideshowXtraOverlay || {};

  Drupal.viewsSlideshowXtraOverlay.transitionBegin = function (options) {
    
    // Hide all overlays for all slides.
    $('#views_slideshow_cycle_main_' + options.slideshowID + ' .views-slideshow-xtra-overlay-row').hide();

    // Show the overlays for the current slide.
    $('#views_slideshow_cycle_main_' + options.slideshowID + ' [id^="views-slideshow-xtra-overlay-"]' + ' .views-slideshow-xtra-overlay-row-' + options.slideNum).each(function() {

      // Get the overlay settings.
      var overlay = $(this);
      var overlayContainerId = overlay.parent().attr('id');
      var settings = Drupal.settings.viewsSlideshowXtraOverlay[overlayContainerId];

      // Fade in or show overlay with optional delay.
      setTimeout(function() {
        if(settings.overlayFadeIn) {
          overlay.fadeIn(settings.overlayFadeIn);    
        } else {
          overlay.show();
        }
      },
        settings.overlayDelay
      );
      
      // Fade out overlay with optional delay.
      if(settings.overlayFadeOut) {
        setTimeout(function() {
          overlay.fadeOut(settings.overlayFadeOut);
        },
        settings.overlayFadeOutDelay
        );
      }
      
    });
  };

  function classList(elem){
    var classList = elem.attr('class').split(/\s+/);
     var classes = new Array(classList.length);
     $.each( classList, function(index, item){
         classes[index] = item;
     });

     return classes;
  }
  
})(jQuery);
